@@ -66,13 +66,16 @@ describe 'keystone::federation::openidc' do
         is_expected.to contain_keystone_config('openid/remote_id_attribute').with_value('<SERVICE DEFAULT>')
       end
 
-      it { is_expected.to contain_concat__fragment('configure_openidc_keystone').with({
-        :target => "10-keystone_wsgi.conf",
-        :order  => params[:template_order],
+      it { is_expected.to contain_apache__vhost__fragment('configure_openidc_keystone').with({
+        :vhost    => 'keystone_wsgi',
+        :priority => 10,
+        :order    => params[:template_order],
       })}
 
+      it { is_expected.to contain_concat('10-keystone_wsgi.conf').with_show_diff(false) }
+
       it 'should contain expected config' do
-        content = get_param('concat::fragment', 'configure_openidc_keystone', 'content')
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
         expect(content).to match('OIDCProviderMetadataURL "https://accounts.google.com/.well-known/openid-configuration"')
         expect(content).to match('OIDCClientID "openid_client_id"')
         expect(content).to match('OIDCClientSecret "openid_client_secret"')
@@ -88,7 +91,7 @@ describe 'keystone::federation::openidc' do
       end
 
       it 'should contain oauth and introspection config' do
-        content = get_param('concat::fragment', 'configure_openidc_keystone', 'content')
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
         expect(content).to match('OIDCOAuthClientID "openid_client_id"')
         expect(content).to match('OIDCOAuthClientSecret "openid_client_secret"')
         expect(content).to match('OIDCOAuthIntrospectionEndpoint "http://example.com"')
@@ -106,7 +109,7 @@ describe 'keystone::federation::openidc' do
       end
 
       it 'should contain oauth and jwks config' do
-        content = get_param('concat::fragment', 'configure_openidc_keystone', 'content')
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
         expect(content).to match('OIDCOAuthVerifyJwksUri "http://example.com"')
         expect(content).to match('/v3/OS-FEDERATION/identity_providers/myidp/protocols/openid/auth')
       end
@@ -125,6 +128,50 @@ describe 'keystone::federation::openidc' do
 
     end
 
+    context 'with memcache options' do
+      before do
+        params.merge!({
+          :openidc_cache_type           => 'memcache',
+          :openidc_cache_shm_max        => 10,
+          :openidc_cache_shm_entry_size => 11,
+          :openidc_cache_dir            => '/var/cache/openidc',
+          :openidc_cache_clean_interval => 12,
+        })
+      end
+
+      it 'should contain memcache servers' do
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
+        expect(content).to match('OIDCCacheType memcache')
+        expect(content).to match('OIDCCacheShmMax 10')
+        expect(content).to match('OIDCCacheShmEntrySize 11')
+        expect(content).to match('OIDCCacheDir /var/cache/openidc')
+        expect(content).to match('OIDCCacheFileCleanInterval 12')
+      end
+    end
+
+    context 'with redis options' do
+      before do
+        params.merge!({
+          :openidc_cache_type    => 'redis',
+          :redis_password        => 'redispass',
+          :redis_username        => 'redisuser',
+          :redis_database        => 0,
+          :redis_timeout         => 10,
+          :redis_connect_timeout => 11,
+        })
+      end
+
+      it 'should contain memcache servers' do
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
+        expect(content).to match('OIDCCacheType redis')
+        expect(content).to match('OIDCRedisCachePassword "redispass"')
+        expect(content).to match('OIDCRedisCacheUsername "redisuser"')
+        expect(content).to match('OIDCRedisCacheDatabase 0')
+        expect(content).to match('OIDCRedisCacheTimeout 10')
+        expect(content).to match('OIDCRedisCacheConnectTimeout 11')
+      end
+    end
+
     context 'with memcached_servers attribute' do
       before do
         params.merge!({
@@ -133,7 +180,7 @@ describe 'keystone::federation::openidc' do
       end
 
       it 'should contain memcache servers' do
-        content = get_param('concat::fragment', 'configure_openidc_keystone', 'content')
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
         expect(content).to match('OIDCMemCacheServers "127.0.0.1:11211 127.0.0.2:11211"')
       end
     end
@@ -146,7 +193,7 @@ describe 'keystone::federation::openidc' do
       end
 
       it 'should contain redis server' do
-        content = get_param('concat::fragment', 'configure_openidc_keystone', 'content')
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
         expect(content).to match('OIDCRedisCacheServer "127.0.0.1"')
       end
     end
@@ -159,7 +206,7 @@ describe 'keystone::federation::openidc' do
       end
 
       it 'should contain OIDC claim delimiter' do
-        content = get_param('concat::fragment', 'configure_openidc_keystone', 'content')
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
         expect(content).to match('OIDCClaimDelimiter ";"')
       end
     end
@@ -172,7 +219,7 @@ describe 'keystone::federation::openidc' do
       end
 
       it 'should contain OIDC pass userinfo as' do
-        content = get_param('concat::fragment', 'configure_openidc_keystone', 'content')
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
         expect(content).to match('OIDCPassUserInfoAs "claims"')
       end
     end
@@ -185,7 +232,7 @@ describe 'keystone::federation::openidc' do
       end
 
       it 'should contain OIDC pass claim as' do
-        content = get_param('concat::fragment', 'configure_openidc_keystone', 'content')
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
         expect(content).to match('OIDCPassClaimsAs "both"')
       end
     end
@@ -198,7 +245,7 @@ describe 'keystone::federation::openidc' do
       end
 
       it 'should contain OIDC response mode' do
-        content = get_param('concat::fragment', 'configure_openidc_keystone', 'content')
+        content = get_param('concat::fragment', 'keystone_wsgi-configure_openidc_keystone', 'content')
         expect(content).to match('OIDCResponseMode "form_post"')
       end
     end
